/*
 * pref-fasterfox.js
 *
 * contains all of the preference dialog handling code
 *
 */

 // create arrays of the form elements for use in the code below
var radioboxes = 	new Array("ff_presets");

var checkboxes = 	new Array("ff_enhancedPrefetching","ff_pipelining","ff_pipeliningFirstRequest","ff_proxyPipelining");

var textboxes = 	new Array("ff_cacheMemoryCapacity","ff_cacheDiskCapacity","ff_maxConnections","ff_maxConnectionsPerServer",
					"ff_maxPersistentConnectionsPerServer","ff_maxPersistentConnectionsPerProxy","ff_maxPipeliningRequests","ff_initialPaintDelay",
					"ff_disablePluginPopups", "ff_dnsCacheExpiration", "ff_dnsCacheEntries");
					
var tabs = 			new Array("ff_Prefetching_tab","ff_Cache_tab","ff_Connection_tab","ff_Pipelining_tab",
					"ff_Rendering_tab","ff_Popups_tab");

// Presets: Default, Good Net Citizen, Optimized, Turbo Charged
var checkboxPresets=new Array([false, false, true, true], [false, false, true, true], [false, false, true, true], [false, false, true, true]);
var textboxPresets =new Array([-1, 65536, 65536, 65536], [50000, 76800, 76800, 76800], [24, 24, 48, 96], [8, 8, 16, 32],
					[2, 2, 4, 12], [4, 4, 12, 24], [4, 4, 6, 8], [250, 0, 0, 0],
					[0, 2, 2, 2], [60, 3600, 3600, 3600], [20, 512, 512, 512]);
				
/*
 * load all preferences into a PrefWindowIV dialog
 * this makes use of the old PrefWindowIV callbacks and functions
 */
function Startup() {
    var i, element, prefstring;
	
	// register the PrefWindowIV OK-button callback
  	parent.hPrefWindow.registerOKCallbackFunc(FF_onOK);
  	
    // initialize the checkboxes
	for (i = 0; i < checkboxes.length; i++) {
  		element = document.getElementById(checkboxes[i]);
    	element.checked = parent.hPrefWindow.getPref("bool", element.getAttribute("prefstring"), false);
  	}

	// initialize the textboxes 
	for (i = 0; i < textboxes.length; i++) {
		element = document.getElementById(textboxes[i]);
		prefstring = element.getAttribute("prefstring");
		element.value = parent.hPrefWindow.getPref("int", prefstring, false);
	}
	
	// initialize the radioboxes 
	for (i = 0; i < radioboxes.length; i++) {
		element = document.getElementById(radioboxes[i]);
		prefstring = element.getAttribute("prefstring");
		element.selectedIndex = parent.hPrefWindow.getPref("int", prefstring, false);
	}

	// Enable the extra tabs if custom is checked, disable if custom is not checked
	if(parent.hPrefWindow.getPref("int", "extensions.fasterfox.preset", 3)==4) {
		FF_displayTabs(false);
	}
	
	// check or uncheck the popups checkbox based on the preference setting
	if(parent.hPrefWindow.getPref("int", "privacy.popups.disable_from_plugins", 2)==2) {
		document.getElementById('ff_disablePluginPopupsCheckbox').checked=true;
	} else {
		document.getElementById('ff_disablePluginPopupsCheckbox').checked=false;
	}

}

/*
 * save all preferences from an old PrefWindowIV dialog
 */
function FF_onOK() {
    var i, value, element;

    try {
	    
		// get the checkboxes and translate them into Booleans
		for (i = 0; i < checkboxes.length; i++) {
			element = document.getElementById(checkboxes[i]);
			value = element.checked;
			parent.hPrefWindow.setPref("bool", element.getAttribute("prefstring"), value);
		}
	
		// get the textbox values and save them
		for (i = 0; i < textboxes.length; i++) {
			element = document.getElementById(textboxes[i]);
			value = element.value;
			parent.hPrefWindow.setPref("int", element.getAttribute("prefstring"), value);
		}
		
		// get the radiobox values and save them
		for (i = 0; i < radioboxes.length; i++) {
			element = document.getElementById(radioboxes[i]);
			value = element.selectedIndex;
			parent.hPrefWindow.setPref("int", element.getAttribute("prefstring"), value);
		}
	
	} catch(e) {
		// the advanced pane is not loaded, so don't bother
		// this is probably dataloss
		return;
	}

}

function FF_setPreset(presetNumber) {
    var i;
    
    // initialize the checkboxes
	for (i = 0; i < checkboxes.length; i++) {
  		document.getElementById(checkboxes[i]).checked = checkboxPresets[i][presetNumber];
  	}
 
	// initialize the textboxes 
	for (i = 0; i < textboxes.length; i++) {
		document.getElementById(textboxes[i]).value = textboxPresets[i][presetNumber];
	}

}

/*
 * Accepts a boolean value which determines whether
 * all tabs should be shown or hidden
 *
 * true = display all tabs
 * false = hide all tabs
 */
function FF_displayTabs(show) {
	var i;
    
    // initialize the checkboxes
	for (i = 0; i < tabs.length; i++) {
    	document.getElementById(tabs[i]).disabled = !show;
  	}

}